@@ -22,6 +22,7 @@
 
 #include "context.h"
 #include "server.h"
+#include "sinkinput.h"
 #include "canberracontext.h"
 #include <pulse/channelmap.h>
 
@@ -116,4 +117,12 @@ void Sink::testChannel(const QString &name)
     ca_proplist_destroy(proplist);
 }
 
+void Sink::switchStreams()
+{
+    auto data = context()->sinkInputs().data();
+    std::for_each(data.begin(), data.end(), [this](SinkInput* paObj) {
+        paObj->setDeviceIndex(m_index);
+    });
+}
+
 } // QPulseAudio
